---
title: <span class="badge object-type-enum"></span> PipelineMetricAggregationType
---
# <span class="badge object-type-enum"></span> PipelineMetricAggregationType

## Definition

```python
class PipelineMetricAggregationType(enum.StrEnum):
    MOVING_AVG = "moving_avg"
    MOVING_FN = "moving_fn"
    DERIVATIVE = "derivative"
    SERIAL_DIFF = "serial_diff"
    CUMULATIVE_SUM = "cumulative_sum"
    BUCKET_SCRIPT = "bucket_script"
```
